###################################################
### chunk number 1: exampleCacher eval=FALSE
###################################################
## library("cacher")
## cacher("myanalysis.R")


###################################################
### chunk number 2: exampleCacherWithLog eval=FALSE
###################################################
## cacher("myanalysis.R", logfile = NA)


###################################################
### chunk number 3: exampleHistoryExpr eval=FALSE
###################################################
## y <- x^2


###################################################
### chunk number 4: simpleExpr eval=FALSE
###################################################
## x <- 1:100


###################################################
### chunk number 1: Setup
###################################################
.oldopt <- options()
.mypager <- function(files, header, title, delete.file = FALSE) {
        for(i in seq_along(files)) {
                f <- files[i]
                tmp <- readLines(f)
                writeLines(tmp, stdout())
        }
}
options(pager = .mypager)
.withMessages <- function(expr) {
        withCallingHandlers(expr, message = function(m) {
                cat(conditionMessage(m))
        })
}
options(useFancyQuotes = FALSE)


###################################################
### chunk number 2: ShowSampleAnalysis
###################################################
writeLines(readLines("sample.R"))


###################################################
### chunk number 3: LoadCacher
###################################################
library("cacher")
options(width = 60)
setConfig("verbose", TRUE)


###################################################
### chunk number 4: callCacher
###################################################
.withMessages(cacher("sample.R"))


###################################################
### chunk number 5: listobjects
###################################################
ls()


###################################################
### chunk number 6: simpleanalysis
###################################################
writeLines(readLines("bigvector.R"))


###################################################
### chunk number 7: evalBigVectorFirstTime
###################################################
systime <- system.time(cacher("bigvector.R"))
print(systime)


###################################################
### chunk number 8: evalBigVectorSecondTime
###################################################
rm(x, s)
systime <- system.time(cacher("bigvector.R"))
print(systime)


###################################################
### chunk number 9: calcpercentile
###################################################
systime <- system.time(q95 <- quantile(x, 0.95))
print(q95)
print(systime)


###################################################
### chunk number 10: cleanAnalyses
###################################################
rm(list = ls())


###################################################
### chunk number 11: showfiles
###################################################
showfiles()


###################################################
### chunk number 12: showCode
###################################################
sourcefile("bigvector.R")
showcode()


###################################################
### chunk number 13: usingCode
###################################################
sourcefile("sample.R")
code()


###################################################
### chunk number 14: showobjects
###################################################
showobjects()
showobjects(8)
showobjects(1)


###################################################
### chunk number 15: loadcache
###################################################
loadcache()
ls()


###################################################
### chunk number 16: summarizeFit
###################################################
print(fit)


###################################################
### chunk number 17: runcodeSample
###################################################
rm(list = ls())
code(1:4)
.withMessages(runcode(1:4))
ls()


###################################################
### chunk number 18: showlogfile
###################################################
writeLines(readLines(file.path(".cache", "log", "sample.R.log"))[1:12])


###################################################
### chunk number 19: runCacherAgain
###################################################
rm(list = ls())
cacher("sample.R")


###################################################
### chunk number 20: showlogfileAgain
###################################################
writeLines(readLines(file.path(".cache", "log", "sample.R.log"))[1:8])


###################################################
### chunk number 21: removeCachePosting
###################################################
unlink(".cache", recursive = TRUE)
rm(list = ls())


###################################################
### chunk number 22: clonecacheBigVector
###################################################
.withMessages(clonecache("bigvector.cache"))


###################################################
### chunk number 23: exploreClonedURLCache
###################################################
showfiles()
sourcefile("bigvector.R")
code()
showobjects()
loadcache()
.withMessages(print(s))


###################################################
### chunk number 24: checkcodeSample
###################################################
unlink(".cache", recursive = TRUE)
.withMessages(clonecache("combined.cache"))
sourcefile("sample.R")
showobjects(1:4)
.withMessages(checkcode(1:4))


###################################################
### chunk number 25: checkcodeBigvector
###################################################
sourcefile("bigvector.R")
.withMessages(checkcode())


###################################################
### chunk number 26: showFaithfulCode
###################################################
unlink(".cache", recursive = TRUE)
rm(list = ls())
writeLines(readLines("faithful.R"))


###################################################
### chunk number 27: cacheFaithful
###################################################
cacher("faithful.R")


###################################################
### chunk number 28: switchDirectory
###################################################
dir.create("tmp", showWarnings = FALSE)
setwd("tmp")
clonecache("../.cache")


###################################################
### chunk number 29: verifyFaithful
###################################################
sourcefile("faithful.R")
.withMessages(checkcode())


###################################################
### chunk number 30: cleanupSwitch
###################################################
unlink(".cache", recursive = TRUE)
setwd("..")
unlink("tmp", recursive = TRUE)


###################################################
### chunk number 31: cleanup
###################################################
unlink(".cache", recursive = TRUE)
options(.oldopt)


###################################################
### chunk number 1: Setup
###################################################
.oldopt <- options()
.mypager <- function(files, header, title, delete.file = FALSE) {
        for(i in seq_along(files)) {
                f <- files[i]
                tmp <- readLines(f)
                writeLines(tmp, stdout())
        }
}
options(pager = .mypager)
.withMessages <- function(expr) {
        withCallingHandlers(expr, message = function(m) {
                cat(conditionMessage(m))
        })
}
options(useFancyQuotes = FALSE)
Sys.setlocale(locale = "C")
setConfig("verbose", TRUE)


###################################################
### chunk number 2: cloneMCAPS
###################################################
library("cacher")
options(width = 60)
.withMessages(clonecache("mcaps.cache"))


###################################################
### chunk number 3: showcode
###################################################
showfiles()
sourcefile("mcaps.R")


###################################################
### chunk number 4: code
###################################################
code(1:7)


###################################################
### chunk number 5: CheckNatlEstimates
###################################################
.withMessages(checkcode(1:7))


###################################################
### chunk number 6: HFrisk
###################################################
loadcache(7)
pooled$gamma


###################################################
### chunk number 7: SensitivityPrior
###################################################
loadcache(1:7)
library("tlnise")
p0 <- with(HF, tlnise(beta, var, prnt = FALSE, prior = 0))
p2 <- with(HF, tlnise(beta, var, prnt = FALSE, prior = 2))


###################################################
### chunk number 8: ShowAltEstimates
###################################################
rbind(p0$gamma, p2$gamma, pooled$gamma)


###################################################
### chunk number 9: cleanup
###################################################
unlink(".cache", recursive = TRUE)
options(.oldopt)


